@@ -12,27 +12,29 @@ This example shows how to use multiple streams.
 
 class Stream:
     def __init__(self) -> None:
-        self._queue = asyncio.Queue[ServerSentEvent]()
+        self._queue = None
+
+    @property
+    def queue(self):
+        if self._queue is None:
+            self._queue = asyncio.Queue[ServerSentEvent]()
+        return self._queue
 
     def __aiter__(self) -> "Stream":
         return self
 
     async def __anext__(self) -> ServerSentEvent:
-        return await self._queue.get()
+        return await self.queue.get()
 
     async def asend(self, value: ServerSentEvent) -> None:
-        await self._queue.put(value)
+        await self.queue.put(value)
 
 
 app = FastAPI()
 
-# _stream = Stream()
 _streams: List[Stream] = []
 
 
-# app.dependency_overrides[Stream] = lambda: _stream
-
-
 @app.get("/sse")
 async def sse(stream: Stream = Depends()) -> EventSourceResponse:
     stream = Stream()
@@ -51,4 +53,4 @@ async def send_message(message: str, stream: Stream = Depends()) -> None:
 if __name__ == "__main__":
     import uvicorn
 
-    uvicorn.run(app, host="127.0.0.1", port=8000)
+    uvicorn.run(app, host="127.0.0.1", port=8000, log_level="trace")
